@@ -43,6 +43,8 @@ mod types;
 /// This number is empirically determined
 const GAS_ON_SUBMIT_VERIFY_SEAL: i64 = 34721049;
 
+const ERR_TOO_MANY_PROVE_COMMITS: ExitCode = ExitCode::new(32);
+
 /// Storage power actor methods available
 #[derive(FromPrimitive)]
 #[repr(u64)]
@@ -72,7 +74,7 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(&*SYSTEM_ACTOR_ADDR))?;
 
         let st = State::new(rt.store()).map_err(|e| {
-            e.downcast_default(ExitCode::ErrIllegalState, "Failed to create power actor state")
+            e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "Failed to create power actor state")
         })?;
         rt.create(&st)?;
         Ok(())
@@ -116,7 +118,7 @@ impl Actor {
         rt.transaction(|st: &mut State, rt| {
             let mut claims =
                 make_map_with_root_and_bitwidth(&st.claims, rt.store(), HAMT_BIT_WIDTH).map_err(
-                    |e| e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims"),
+                    |e| e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims"),
                 )?;
             set_claim(
                 &mut claims,
@@ -129,7 +131,7 @@ impl Actor {
             )
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to put power in claimed table while creating miner",
                 )
             })?;
@@ -137,7 +139,7 @@ impl Actor {
 
             st.update_stats_for_new_miner(window_post_proof_type).map_err(|e| {
                 actor_error!(
-                    ErrIllegalState,
+                    USR_ILLEGAL_STATE,
                     "failed to update power stats for new miner {}: {}",
                     &id_address,
                     e
@@ -145,7 +147,7 @@ impl Actor {
             })?;
 
             st.claims = claims.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush claims")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush claims")
             })?;
             Ok(())
         })?;
@@ -168,7 +170,7 @@ impl Actor {
         rt.transaction(|st: &mut State, rt| {
             let mut claims =
                 make_map_with_root_and_bitwidth(&st.claims, rt.store(), HAMT_BIT_WIDTH).map_err(
-                    |e| e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims"),
+                    |e| e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims"),
                 )?;
 
             st.add_to_claim(
@@ -179,7 +181,7 @@ impl Actor {
             )
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!(
                         "failed to update power raw {}, qa {}",
                         params.raw_byte_delta, params.quality_adjusted_delta,
@@ -188,7 +190,7 @@ impl Actor {
             })?;
 
             st.claims = claims.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush claims")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush claims")
             })?;
             Ok(())
         })
@@ -211,7 +213,7 @@ impl Actor {
         // Ensure it is not possible to enter a large negative number which would cause
         // problems in cron processing.
         if params.event_epoch < 0 {
-            return Err(actor_error!(ErrIllegalArgument;
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT;
                 "cron event epoch {} cannot be less than zero", params.event_epoch));
         }
 
@@ -223,15 +225,15 @@ impl Actor {
                 CRON_QUEUE_AMT_BITWIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to load cron events")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load cron events")
             })?;
 
             st.append_cron_event(&mut events, params.event_epoch, miner_event).map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to enroll cron event")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to enroll cron event")
             })?;
 
             st.cron_event_queue = events.root().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush cron events")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush cron events")
             })?;
             Ok(())
         })?;
@@ -294,7 +296,7 @@ impl Actor {
             st.add_pledge_total(pledge_delta);
             if st.total_pledge_collateral.is_negative() {
                 return Err(actor_error!(
-                    ErrIllegalState,
+                    USR_ILLEGAL_STATE,
                     "negative total pledge collateral {}",
                     st.total_pledge_collateral
                 ));
@@ -325,7 +327,7 @@ impl Actor {
                 )
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         "failed to load proof batching set",
                     )
                 })?
@@ -336,24 +338,28 @@ impl Actor {
             let miner_addr = rt.message().caller();
             let arr = mmap.get::<SealVerifyInfo>(&miner_addr.to_bytes()).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to get seal verify infos at addr {}", miner_addr),
                 )
             })?;
             if let Some(arr) = arr {
                 if arr.count() >= MAX_MINER_PROVE_COMMITS_PER_EPOCH {
-                    return Err(actor_error!(ErrTooManyProveCommits;
-                        "miner {} attempting to prove commit over {} sectors in epoch",
-                        miner_addr, MAX_MINER_PROVE_COMMITS_PER_EPOCH));
+                    return Err(ActorError::new(
+                        ERR_TOO_MANY_PROVE_COMMITS,
+                        format!(
+                            "miner {} attempting to prove commit over {} sectors in epoch",
+                            miner_addr, MAX_MINER_PROVE_COMMITS_PER_EPOCH
+                        ),
+                    ));
                 }
             }
 
             mmap.add(miner_addr.to_bytes().into(), seal_info).map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to insert proof into set")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to insert proof into set")
             })?;
 
             let mmrc = mmap.root().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush proofs batch map")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush proofs batch map")
             })?;
 
             rt.charge_gas("OnSubmitVerifySeal", GAS_ON_SUBMIT_VERIFY_SEAL);
@@ -539,18 +545,18 @@ impl Actor {
                 CRON_QUEUE_AMT_BITWIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to load cron events")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load cron events")
             })?;
 
             let claims =
                 make_map_with_root_and_bitwidth::<_, Claim>(&st.claims, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
-                        e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims")
+                        e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims")
                     })?;
             for epoch in st.first_cron_epoch..=rt_epoch {
                 let epoch_events = load_cron_events(&events, epoch).map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to load cron events at {}", epoch),
                     )
                 })?;
@@ -562,7 +568,10 @@ impl Actor {
                 for evt in epoch_events.into_iter() {
                     let miner_has_claim =
                         claims.contains_key(&evt.miner_addr.to_bytes()).map_err(|e| {
-                            e.downcast_default(ExitCode::ErrIllegalState, "failed to look up claim")
+                            e.downcast_default(
+                                ExitCode::USR_ILLEGAL_STATE,
+                                "failed to look up claim",
+                            )
                         })?;
                     if !miner_has_claim {
                         debug!("skipping cron event for unknown miner: {}", evt.miner_addr);
@@ -573,7 +582,7 @@ impl Actor {
 
                 events.remove_all(&epoch_key(epoch)).map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to clear cron events at {}", epoch),
                     )
                 })?;
@@ -581,7 +590,7 @@ impl Actor {
 
             st.first_cron_epoch = rt_epoch + 1;
             st.cron_event_queue = events.root().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush events")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush events")
             })?;
 
             Ok(())
@@ -615,7 +624,7 @@ impl Actor {
                 let mut claims =
                     make_map_with_root_and_bitwidth(&st.claims, rt.store(), HAMT_BIT_WIDTH)
                         .map_err(|e| {
-                            e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims")
+                            e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims")
                         })?;
 
                 // Remove power and leave miner frozen
@@ -632,7 +641,7 @@ impl Actor {
                 }
 
                 st.claims = claims.flush().map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to flush claims")
+                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush claims")
                 })?;
                 Ok(())
             })?;
@@ -685,7 +694,7 @@ impl ActorCode for Actor {
                 let res = Self::current_total_power(rt)?;
                 Ok(RawBytes::serialize(res)?)
             }
-            None => Err(actor_error!(SysErrInvalidMethod; "Invalid method")),
+            None => Err(actor_error!(SYS_INVALID_METHOD; "Invalid method")),
         }
     }
 }
